version = "0.0.4"

name = "localfunk"
author = "Adam Baker"
author_email = "adambaker@keemail.me"
description = "Proxy Lambda functions to local code"
license = "MIT"
homepage = "https://github.com/atomraymaker/localfunk"
